@@ -45,7 +45,9 @@ class MemoryFile(io.RawIOBase):
 
     __slots__ = ['_data', '_cursor']
 
-    def __init__(self, data: ByteString):
+    def __init__(self, data: Optional[ByteString] = None):
+        if data is None:
+            data = bytearray()
         self._data = data
         self._cursor = 0
 
@@ -87,7 +89,7 @@ class MemoryFile(io.RawIOBase):
 
     @property
     def eof(self) -> bool:
-        return self._cursor >= len(self._data)
+        return self.closed() or self._cursor >= len(self._data)
 
     def writable(self):
         if self.closed():
@@ -97,6 +99,9 @@ class MemoryFile(io.RawIOBase):
         return isinstance(self._data, bytearray)
 
     def read(self, size=-1) -> ByteString:
+        return self.read1(size)
+
+    def read1(self, size=-1) -> ByteString:
         beginning = self._cursor
         if size is None or size < 0:
             self._cursor = len(self._data)
@@ -147,6 +152,9 @@ class MemoryFile(io.RawIOBase):
     def getbuffer(self) -> ByteString:
         return self._data
 
+    def getvalue(self) -> ByteString:
+        return self._data
+
     def seek(self, offset, whence=io.SEEK_SET) -> int:
         if whence == io.SEEK_SET:
             if offset < 0:
@@ -217,7 +225,7 @@ class StructReader(MemoryFile):
         self._nbits = 0
         return super().seek(offset, whence)
 
-    def read(self, size: Optional[int] = None):
+    def read1(self, size: Optional[int] = None):
         """
         Read bytes from the underlying stream. Raises a `RuntimeError` when the stream is not currently
         byte-aligned, i.e. when `refinery.lib.structures.StructReader.byte_aligned` is `False`. Raises
@@ -228,7 +236,7 @@ class StructReader(MemoryFile):
         """
         if not self.byte_aligned:
             raise StructReader.Unaligned('buffer is not byte-aligned')
-        data = super().read(size)
+        data = super().read1(size)
         if len(data) != size:
             raise EOF(data)
         return data
