@@ -11,10 +11,9 @@ class carveb64z(carve):
     """
     def __init__(
         self, single: arg.switch('-m', '--multi', help='Process all base64 strings instead of just the longest.') = True,
-        min=1, max=None, stripspace=False, unique=False, longest=False, take=None, utf16=True, ascii=True
+        min=1, max=None, stripspace=False, duplicates=False, longest=False, take=None, utf16=True, ascii=True
     ):
-        super().__init__('b64', decode=True,
-            single=single, min=min, max=max, stripspace=stripspace, unique=unique, longest=longest, take=take, utf16=utf16, ascii=ascii)
+        self.superinit(super(), format='b64', decode=True, **vars())
         self.decompressor = decompress()
 
     def process(self, data):
